@@ -52,6 +52,5 @@ test_that("download multiple files with file id - with folders", {
 test_that("More informative error message when file does not exist", {
   testthat::skip_on_cran()
   # wrong server
-  expect_error(get_file(2972336, server = "demo.dataverse.org"),
-               regexp = "API endpoint does not exist on this server")
+  expect_error(get_file(2972336, server = "demo.dataverse.org"), regexp = "API")
 })
